from setuptools import setup

setup(
    name='UCI_Package',
    version='0.1.0',
    description='Utilities from DCI Class',
    author='Ibad',
    packages=['UCI_Package'],
    python_requires='>=3.6',
    install_requires=[],
    classifiers=[
        'Development Status :: 3 - Alpha',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
    ],
)
